const express = require('express');

const cityApp = express.Router();

const libs = `${process.cwd()}/libs`;

const squel = require('squel');

const query = require(`${libs}/middlewares/query`);

const response = require(`${libs}/middlewares/response`);

// Return all cities
cityApp.get('/', (req, res, next) => {
    req.sql.from('municipio');
    next();
}, query, response('city'));

// Return a specific city by it's id
cityApp.get('/:id', (req, res, next) => {
    req.sql.from('municipio')
        .where('pk_cod_ibge = ?', parseInt(req.params.id, 10));
    next();
}, query, response('city'));

// Return a specific city by it's IBGE code
cityApp.get('/ibge/:id', (req, res, next) => {
    req.sql.from('municipio')
        .where('pk_cod_ibge = ?', parseInt(req.params.id, 10));
    next();
}, query, response('city'));

// Return all the cities from a specific state
cityApp.get('/state/:id', (req, res, next) => {
    req.sql.from('municipio')
        .where('fk_estado_id = ?', parseInt(req.params.id, 10));
    next();
}, query, response('city'));

module.exports = cityApp;
